##  Summary
In this tutorial, you learned how to import application fact sheets and update them using the inboundFactSheet inbound processor of the Integration API. You also learned how to set up value mappings in the processor configuration.
